@@ -10,7 +10,6 @@
 #include "Config.h"
 #include "SpectacleCore.h"
 #include "Gui/ExportMenu.h"
-#include "spectacle_gui_debug.h"
 
 #include <KUrlMimeData>
 #include <Kirigami/Platform/Units>
@@ -176,9 +175,10 @@ void ViewerWindow::showLocationCopiedMessage()
     showInlineMessage("%1/Gui/LocationCopiedMessage.qml"_L1.arg(SPECTACLE_QML_PATH), {});
 }
 
-void ViewerWindow::showScreenshotFailedMessage()
+void ViewerWindow::showScreenshotFailedMessage(const QString &messageArgument)
 {
-    showInlineMessage("%1/Gui/ScreenshotFailedMessage.qml"_L1.arg(SPECTACLE_QML_PATH), {});
+    showInlineMessage("%1/Gui/ScreenshotFailedMessage.qml"_L1.arg(SPECTACLE_QML_PATH),
+                      {{"messageArgument"_L1, messageArgument}});
 }
 
 void ViewerWindow::showRecordingFailedMessage(const QString &messageArgument)
@@ -187,6 +187,11 @@ void ViewerWindow::showRecordingFailedMessage(const QString &messageArgument)
                       {{"messageArgument"_L1, messageArgument}});
 }
 
+void ViewerWindow::showQRCodeScannedMessage(const QVariant &messageArgument)
+{
+    showInlineMessage("%1/Gui/QRCodeScannedMessage.qml"_L1.arg(SPECTACLE_QML_PATH), {{"messageArgument"_L1, messageArgument}});
+}
+
 void ViewerWindow::showImageSharedMessage(int errorCode, const QString &messageArgument)
 {
     if (errorCode == 1 || status() != QQuickView::Ready) {
