@@ -7,27 +7,13 @@
 #include "Platforms/VideoPlatform.h"
 
 #include <QAbstractListModel>
-#include <QQmlEngine>
 
 class RecordingModeModel : public QAbstractListModel
 {
     Q_OBJECT
-    QML_ELEMENT
-    QML_SINGLETON
     Q_PROPERTY(int count READ rowCount NOTIFY countChanged FINAL)
 public:
-    explicit RecordingModeModel(QObject *parent = nullptr);
-
-    static RecordingModeModel *instance();
-
-    static RecordingModeModel *create(QQmlEngine *engine, QJSEngine *)
-    {
-        auto inst = instance();
-        Q_ASSERT(inst);
-        Q_ASSERT(inst->thread() == engine->thread());
-        QJSEngine::setObjectOwnership(inst, QJSEngine::CppOwnership);
-        return inst;
-    }
+    RecordingModeModel(VideoPlatform::RecordingModes modes, QObject *parent = nullptr);
 
     enum {
         RecordingModeRole = Qt::UserRole + 1,
@@ -39,13 +25,8 @@ public:
 
     int indexOfRecordingMode(VideoPlatform::RecordingMode mode) const;
 
-    void setRecordingModes(VideoPlatform::RecordingModes modes);
-
-    static QString recordingModeLabel(VideoPlatform::RecordingMode mode);
-
 Q_SIGNALS:
     void countChanged();
-    void recordingModesChanged();
 
 private:
     struct Item {
