@@ -11,6 +11,7 @@
 #include "ExportManager.h"
 #include "Geometry.h"
 #include "Gui/Annotations/AnnotationViewport.h"
+#include "Gui/Annotations/QmlPainterPath.h"
 #include "Gui/CaptureWindow.h"
 #include "Gui/Selection.h"
 #include "Gui/SelectionEditor.h"
@@ -25,7 +26,7 @@
 // generated
 #include "Config.h"
 #include "settings.h"
-#include "spectacle_core_debug.h"
+#include "DebugUtils.h"
 
 #include <KFormat>
 #include <KGlobalAccel>
@@ -159,6 +160,7 @@ SpectacleCore::SpectacleCore(QObject *parent)
             syncExportImage();
             showViewerIfGuiMode();
             SpectacleWindow::setTitleForAll(SpectacleWindow::Unsaved);
+            ExportManager::instance()->scanQRCode();
             const auto &exportActions = actions & ExportManager::AnyAction ? actions : autoExportActions();
             ExportManager::instance()->exportImage(exportActions, outputUrl());
         }
@@ -166,24 +168,63 @@ SpectacleCore::SpectacleCore(QObject *parent)
 
     connect(imagePlatform, &ImagePlatform::newScreenshotTaken, this, [this](const QImage &image){
         m_annotationDocument->clearAnnotations();
-        m_annotationDocument->setImage(image);
+        m_annotationDocument->setBaseImage(image);
         setExportImage(image);
         ExportManager::instance()->updateTimestamp();
         showViewerIfGuiMode();
         SpectacleWindow::setTitleForAll(SpectacleWindow::Unsaved);
+        ExportManager::instance()->scanQRCode();
         ExportManager::instance()->exportImage(autoExportActions(), outputUrl());
         setVideoMode(false);
     });
     connect(imagePlatform, &ImagePlatform::newCroppableScreenshotTaken, this, [this](const QImage &image) {
+        setVideoMode(false);
         m_annotationDocument->clearAnnotations();
-        m_annotationDocument->setImage(image);
+        m_annotationDocument->setBaseImage(image);
         SelectionEditor::instance()->reset();
-
         initCaptureWindows(CaptureWindow::Image);
         SpectacleWindow::setTitleForAll(SpectacleWindow::Unsaved);
         SpectacleWindow::setVisibilityForAll(QWindow::FullScreen);
     });
-    connect(imagePlatform, &ImagePlatform::newScreenshotFailed, this, &SpectacleCore::onScreenshotFailed);
+    connect(imagePlatform, &ImagePlatform::newScreenshotFailed, this, [this](const QString message) {
+        auto uiMessage = i18nc("@info", "An error occurred while taking a screenshot.");
+        if (!message.isEmpty()) {
+            uiMessage = uiMessage % u"\n"_s % message;
+        }
+        const auto &windows = qGuiApp->allWindows();
+        const bool hasVisibleWindow = std::any_of(windows.cbegin(), windows.cend(), [](auto *window){
+            return window->isVisible();
+        });
+        switch (m_startMode) {
+        case StartMode::Background:
+            showErrorMessage(uiMessage);
+            if (!hasVisibleWindow) {
+                Q_EMIT allDone();
+            }
+            return;
+        case StartMode::DBus: {
+            showErrorMessage(uiMessage);
+            Q_EMIT dbusScreenshotFailed(message);
+            if (!hasVisibleWindow) {
+                Q_EMIT allDone();
+            }
+            return;
+        }
+        case StartMode::Gui: {
+            if (!ViewerWindow::instance() && hasVisibleWindow) {
+                showErrorMessage(uiMessage);
+                return;
+            } else if (!ViewerWindow::instance()) {
+                initViewerWindow(ViewerWindow::Dialog);
+            }
+            qWarning().noquote() << message;
+            auto viewer = ViewerWindow::instance();
+            viewer->setVisible(true);
+            viewer->showScreenshotFailedMessage(uiMessage);
+            return;
+        }
+        }
+    });
 
     // set up the export manager
     auto exportManager = ExportManager::instance();
@@ -263,6 +304,16 @@ SpectacleCore::SpectacleCore(QObject *parent)
         }
     };
     connect(exportManager, &ExportManager::videoExported, this, onVideoExported);
+
+    auto onQRCodeScanned = [](const QVariant &result) {
+        auto viewerWindow = ViewerWindow::instance();
+        if (!viewerWindow) {
+            return;
+        }
+        viewerWindow->showQRCodeScannedMessage(result);
+    };
+    connect(exportManager, &ExportManager::qrCodeScanned, this, onQRCodeScanned);
+
     connect(exportManager, &ExportManager::errorMessage, this, &SpectacleCore::showErrorMessage);
 
     connect(imagePlatform, &ImagePlatform::windowTitleChanged, exportManager, &ExportManager::setWindowTitle);
@@ -355,7 +406,7 @@ SpectacleCore::SpectacleCore(QObject *parent)
             Q_EMIT allDone();
             return;
         case StartMode::DBus:
-            Q_EMIT dbusRecordingFailed();
+            Q_EMIT dbusRecordingFailed(message);
             Q_EMIT allDone();
             return;
         case StartMode::Gui:
@@ -558,7 +609,7 @@ void SpectacleCore::activate(const QStringList &arguments, const QString &workin
             // This QImage constructor only works with local files or Qt resource file names.
             QImage existingImage(existingLocalFile);
             m_annotationDocument->clearAnnotations();
-            m_annotationDocument->setImage(existingImage);
+            m_annotationDocument->setBaseImage(existingImage);
             showViewerIfGuiMode();
             SpectacleWindow::setTitleForAll(SpectacleWindow::Saved, m_editExistingUrl.fileName());
             return;
@@ -672,7 +723,7 @@ void SpectacleCore::activate(const QStringList &arguments, const QString &workin
                 bool isCaptureWindow = !CaptureWindow::instances().isEmpty();
                 SpectacleWindow *window = nullptr;
                 if (isCaptureWindow) {
-                    window = CaptureWindow::instances().front();
+                    window = CaptureWindow::instances().constFirst();
                 } else {
                     window = ViewerWindow::instance();
                 }
@@ -788,9 +839,9 @@ void SpectacleCore::cancelScreenshot()
 
 void SpectacleCore::showErrorMessage(const QString &message)
 {
-    qCDebug(SPECTACLE_CORE_LOG) << "ERROR: " << message;
+    qWarning().noquote() << message;
 
-    if (m_startMode == StartMode::Gui) {
+    if (m_startMode == StartMode::Gui || m_startMode == StartMode::DBus) {
         KMessageBox::error(nullptr, message);
     }
 }
@@ -811,26 +862,6 @@ void SpectacleCore::showViewerIfGuiMode(bool minimized)
     }
 }
 
-void SpectacleCore::onScreenshotFailed()
-{
-    switch (m_startMode) {
-    case StartMode::Background:
-        showErrorMessage(i18n("Screenshot capture canceled or failed"));
-        Q_EMIT allDone();
-        return;
-    case StartMode::DBus:
-        Q_EMIT dbusScreenshotFailed();
-        Q_EMIT allDone();
-        return;
-    case StartMode::Gui:
-        if (!ViewerWindow::instance()) {
-            initViewerWindow(ViewerWindow::Dialog);
-        }
-        ViewerWindow::instance()->showScreenshotFailedMessage();
-        return;
-    }
-}
-
 static QList<KNotification *> notifications;
 
 void SpectacleCore::doNotify(ScreenCapture type, const ExportManager::Actions &actions, const QUrl &saveUrl)
@@ -1055,11 +1086,14 @@ QQmlEngine *SpectacleCore::getQmlEngine()
         qmlRegisterSingletonInstance(SPECTACLE_QML_URI, 1, 0, "AnnotationDocument", m_annotationDocument.get());
         qmlRegisterUncreatableType<AnnotationTool>(SPECTACLE_QML_URI, 1, 0, "AnnotationTool",
                                                    u"Use AnnotationDocument.tool"_s);
-        qmlRegisterUncreatableType<SelectedActionWrapper>(SPECTACLE_QML_URI, 1, 0, "SelectedAction",
-                                                          u"Use AnnotationDocument.selectedAction"_s);
+        qmlRegisterUncreatableType<SelectedItemWrapper>(SPECTACLE_QML_URI, 1, 0, "SelectedItem",
+                                                          u"Use AnnotationDocument.selectedItem"_s);
         qmlRegisterType<AnnotationViewport>(SPECTACLE_QML_URI, 1, 0, "AnnotationViewport");
         qmlRegisterUncreatableType<QScreen>(SPECTACLE_QML_URI, 1, 0, "QScreen",
                                             u"Only created by Qt"_s);
+        qmlRegisterExtendedUncreatableType<QPainterPath, QmlPainterPath>(SPECTACLE_QML_URI, 1, 0,
+                                                                         "QmlPainterPath",
+                                                                         u"Only created from C++"_s);
     }
     return m_engine.get();
 }
@@ -1079,6 +1113,13 @@ void SpectacleCore::initCaptureWindows(CaptureWindow::Mode mode)
     auto engine = getQmlEngine();
     const auto screens = qApp->screens();
     for (auto *screen : screens) {
+        const auto screenRect = Geometry::mapFromPlatformRect(screen->geometry(), screen->devicePixelRatio());
+        // Don't show windows for screens that don't have an image.
+        if (!m_videoMode
+            && !m_annotationDocument->baseImage().isNull()
+            && !screenRect.intersects(m_annotationDocument->canvasRect())) {
+            continue;
+        }
         m_captureWindows.emplace_back(CaptureWindow::makeUnique(mode, screen, engine));
     }
 }
